What the Airlines Did Well in 2014 - Condé Nast Traveler
Author: Cynthia Drescher
Description: Not often do the airlines receive praise from their passengers, but 2014 was the year airlines refreshed, rebranded, and reconsidered the flight experience.
Date: 2014-12-24T16:00:00.000Z

### Sign Up for Free Traveler Newsletters

Enter your email address

Please enter a valid email.

We encountered a server error. Please try again later.

Please select a newsletter

Will be used in accordance with our Privacy Policy

The Daily TravelerDaily inspiration Travel IntelWeekly news and advice

### Thank you!

We've sent you an email to confirm your subscription.

×
Conde Nast Traveler

##### At Home in the World

###

- Share on Facebook.
- Tweet it!
- Pin It!
- Share on Google Plus.
- Share on LinkedIn.
- Print this Page
- Email to a Friend

Subscribe

Subscribe Now

### Share this Slideshow

- Share on Facebook.
- Tweet it!
- Pin It!
- Share on Google Plus.
- Share on LinkedIn.
- Print this Page
- Email to a Friend

## Around The Web

Powered by ZergNet

# What the Airlines Did Well in 2014

Not often do the airlines receive praise from their passengers, but 2014 was the year airlines refreshed, rebranded, and reconsidered the flight experience. See what moves the airlines made this year to make travelers happier.

## U.S. airlines competed to be the best at transporting passengers

A full-on airline arms race broke out this year as both American and JetBlue (pictured) debuted their newest, shiniest airplanes on transcontinental routes. These Airbus A321s come with flat-bed seats for premium classes and state-of-the-art in-flight entertainment for all. Delta and United played catch-up, updating their older 757s with flat-bed seats in business class.

## Dated airplane interiors were upcycled

Southwest, Delta, American, and other airlines worked through 2014 to freshen up their airplane cabins. Though passengers may not notice the new seat covers, communities on the other side of the world are grateful for the soccer balls, shoes, and other items made from the old materials. Southwest in particular donated 43 acres of leather to be reused in Kenya.

## Wi-Fi use was approved during all stages of a flight

In 2013, the Federal Aviation Administration gave the green light for gadgets to remain on during an entire flight, but U.S. airlines still had to prove to the FAA that passengers could safely use their gadgets in Airplane Mode from gate to gate. In 2014, U.S. airlines made their case, and carriers in the U.K. and Europe followed. The new freedom to read a Kindle, use a travel app, or watch videos on takeoff is a victory over boredom.

## Airlines partnered with craft breweries

Airlines opened their galley carts to new beverage offerings in 2014, with a clear focus on beer. Hawaiian Airlines partnered with Maui Brewing Co., United with Goose Island, Delta with Sweetwater Brewing, Southwest with New Belgium, Alaska Airlines with Silver Gulch Brewing, and SAS with Mikkeller to tempt travelers with more than the usual can of “whatever’s onboard.”

## Ryanair turned on the charm to attract more traveling families.

European budget airline Ryanair decided 2014 was the year to improve its image by taking a “family-friendly” approach. It ditched its offensive ad campaigns and calendar of scantily clad flight attendants, lowered baggage fees, increased baggage allowances, upped its bare-bones offerings, updated its website, and joined Twitter.

## Dallas's smaller airport opened up

The restrictive Wright Amendment, signed into law in 1980, banned nonstop flights from Dallas Love Field to destinations farther than Louisiana, Arkansas, Oklahoma, and New Mexico. The point was to encourage more business at the newer Dallas/Fort Worth International Airport. Now that the amendment has been lifted, Texas travelers can take advantage of lower fares, more nonstop destinations, and Love’s easy proximity to downtown Dallas.

## Airline lounges ditched the corporate look for sleek redesigns

The generic framed art and chairs better befitting a doctor’s office are done and gone. Some airlines, including Cathay Pacific, Singapore Airlines, American Airlines, and Delta, used 2014 to introduce designer seating, “productivity pods” with plentiful power outlets, and even buffets with healthful food for those holding premium tickets.

## American Airlines highlighted classic Hollywood glamour.

Grace Kelly and Gregory Peck knew how to travel in great style. So American Airlines took 1950s images of these Hollywood icons flying AA and paired them with images of contemporary stars—Julianna Margulies, Neil Patrick Harris—to connect the glamour of the past with its new first class. The results dazzled travelers used to the usual ad focus on just the seats.

## Self-service boarding gates eased “gate lice"

In an effort to alleviate the confused jumble of passengers near a boarding gate, airlines added self-scanning devices at U.S. airports. Travelers simply scan their own boarding document, pass through a gate, and head down the jetway to the plane. British Airways and JetBlue are already using the gates at Las Vegas-McCarran Airport, Delta has run trials at Hartsfield-Jackson Atlanta International Airport, and United has installed a few test gates at Houston George Bush Intercontinental Airport.

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
Where in the world are you thinking of?
Share This

- Share on Facebook.
- Tweet it!
- Pin It!
- Share on Google Plus.
- Share on LinkedIn.
- Print this Page
- Email to a Friend

×
An Error occurred while compiling your sass files. :(
Please find out what went wrong by consulting your friendly terminal.
We are sorry for any inconvenience this may have caused you.